Struct RoomCreationOptions
pub struct RoomCreationOptions {
pub name: Option<String>,
pub topic: Option<String>,
pub invites: Vec<String>,
pub visibility: Option<RoomVisibility>,
pub encryption: Option<bool>,
}Expand description
Room creation options shared by channel implementations that support creating group conversations.
Fields
name: Option<String>topic: Option<String>invites: Vec<String>visibility: Option<RoomVisibility>encryption: Option<bool>Trait Implementations
Sourceimpl Clone for RoomCreationOptions
impl Clone for RoomCreationOptions
Sourcefn clone(&self) -> RoomCreationOptions
fn clone(&self) -> RoomCreationOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoomCreationOptions
impl Debug for RoomCreationOptions
Sourceimpl Default for RoomCreationOptions
impl Default for RoomCreationOptions
Sourcefn default() -> RoomCreationOptions
fn default() -> RoomCreationOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RoomCreationOptions
impl<'de> Deserialize<'de> for RoomCreationOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RoomCreationOptions
impl PartialEq for RoomCreationOptions
Sourcefn eq(&self, other: &RoomCreationOptions) -> bool
fn eq(&self, other: &RoomCreationOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RoomCreationOptions
impl Serialize for RoomCreationOptions
impl Eq for RoomCreationOptions
impl StructuralPartialEq for RoomCreationOptions