Function is_android
pub fn is_android() -> boolExpand description
Returns true when the current runtime environment exposes Android’s system shell path.
pub fn is_android() -> boolReturns true when the current runtime environment exposes Android’s system shell path.